genesys is a file management and version control software that is directly intigrated with kitsu.

genesys requires a sligthly modified version of zou

docker images of our modified [zou](https://hub.docker.com/repository/docker/eaxum/zou) and [genesys](https://hub.docker.com/repository/docker/eaxum/genesys) are availble on docker hub

Genesys is built and managed by Eaxum

[![Eaxum Logo](https://eaxum.com/wp-content/uploads/2020/07/LogoCapsule_small-300x113.png)](https://eaxum.com)